# SPDX-License-Identifier: GPL-3.0-or-later
# SPDX-FileCopyrightText: Copyright contributors to the OpenScanHub project.

"""
Instance-specific settings.

Devel instance
"""

import os

from osh.hub.other.settings_util import get_secret

DEBUG = True

# where to read API keys from
SECRETS_DIR = ".secrets"

ADMINS = (
    ('Kamil Dudka', 'kdudka@redhat.com'),
)

MANAGERS = ADMINS

DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.postgresql',
        'NAME': 'openscanhub',
        'USER': 'openscanhub',
        'PASSWORD': get_secret('db_password', SECRETS_DIR) or 'velryba',
        'HOST': 'db',
        'PORT': '5432',
        'TEST': {
                'NAME': 'openscanhub-test',
        },
    },
}

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'verbose': {
            'format': '%(levelname)-7s %(asctime)s %(pathname)-50s:%(lineno)d %(funcName)s   %(message)s'
        },
        'simple': {
            'format': '%(levelname)s %(message)s'
        },
    },
    'handlers': {
        'file': {
            'level': 'DEBUG',
            'class': 'logging.handlers.RotatingFileHandler',
            'formatter': 'verbose',
            'filename': '/var/tmp/osh.hub.log',
            'maxBytes': 10 * (1024 ** 2),  # 10 MB
            'backupCount': 14,
        },
        'console': {
            'level': 'DEBUG',
            'class': 'logging.StreamHandler',
            'formatter': 'verbose',
        }
    },
    'loggers': {
        'osh': {
            'handlers': ['file', 'console'],
            'level': 'DEBUG',
            'propagate': True,
        },
        # 'django.db.backends': {
        #     'handlers': ['file'],
        #     'propagate': False,
        #     'level': 'INFO',
        # },
        'kobo': {
            'handlers': ['file'],
            'level': 'DEBUG',
            'propagate': True,
        }
    }
}

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# On Unix systems, a value of None will cause Django to use the same
# timezone as the operating system.
# If running in a Windows environment this must be set to the same as your
# system time zone.
TIME_ZONE = 'Europe/Prague'

# KRB_AUTH_PRINCIPAL =
# KRB_AUTH_KEYTAB =

# Regular users cannot bind to port 25.
EMAIL_PORT = 8025

###############################################################################
# OpenScanHub SPECIFIC
###############################################################################

# Path to task logs and other files
FILES_PATH = './osh/hub'

# Files for kobo tasks with predefined structure
TASK_DIR = os.path.join(FILES_PATH, 'tasks')

# Root directory for uploaded files
UPLOAD_DIR = os.path.join(FILES_PATH, 'upload')

BZ_URL = "https://bugzilla.stage.redhat.com"
JIRA_URL = "https://issues.stage.redhat.com"

ET_URL = 'https://errata-web-01.host.stage.eng.bos.redhat.com'

UMB_BROKER_URLS = [
    'amqps://umb-broker01.stage.api.redhat.com:5671',
    'amqps://umb-broker02.stage.api.redhat.com:5671',
    'amqps://umb-broker03.stage.api.redhat.com:5671',
    'amqps://umb-broker04.stage.api.redhat.com:5671',
    'amqps://umb-broker05.stage.api.redhat.com:5671',
    'amqps://umb-broker06.stage.api.redhat.com:5671']

UMB_CLIENT_CERT = '/etc/osh/hub/msg-client-osh.pem'
# UMB_TOPIC_PREFIX can be a single string or a collection of strings.
# Every UMB message will be sent to all defined UMB topic prefixes.
UMB_TOPIC_PREFIX = 'topic://VirtualTopic.eng.openscanhub.scan'

# E-mail address used in the From: field of notifications generated by OpenScanHub
NOTIFICATION_EMAIL_ADDRESS = "no-reply@example.org"
# E-mail address where notifications about failed/cancelled tasks are sent
DEVEL_EMAIL_ADDRESS = "no-reply@example.org"

# Default e-mail domain name for sending notifications to the user.
# It is used when `email` field in the user model is not set.
DEFAULT_EMAIL_DOMAIN = "example.org"

NOTIFICATION_EMAIL_FOOTER = "This is a test footer."

# Dictionary with extra yum repositories for the special `auto` mock config.
# The keys are regular expressions that will match the given build tag, e.g.
# r'f\d+' for Fedora X.  The value is a corresponding repofile which will be
# then appended to all generated mock configs, e.g.:
# MOCK_AUTO_EXTRA_REPOS = {r'f\d+': '[repo]\n...'}
MOCK_AUTO_EXTRA_REPOS = {}

# If this setting is enabled, a worker is only used to perform a single task.
ENABLE_SINGLE_USE_WORKERS = False

# This number should be same as the `max` field in the `/etc/resallocserver/pools.yaml`
# on the resalloc server. Otherwise, we may end up with too few or too many tickets
# being opened.
MAX_SINGLE_USE_WORKERS = 8

# This user is used to ssh to newly created worker.
SINGLE_USE_WORKER_SSH_USER = ""

# TODO: What should we use here if we want to deploy across multiple clouds?
# May be, related public key should be copied when a new worker is set up.
SINGLE_USE_WORKER_SSH_PRIVATE_KEY = ""

# This url is used to dynamically generate worker configuration files.
SINGLE_USE_WORKER_OSH_HUB_URL = ""

ALLOWED_HOSTS = ['*']
